using AutoMapper;
using CatalogService.Data;
using CatalogService.DTOs;
using CatalogService.Entities;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Shared.DTOs;

namespace CatalogService.Controllers;

[ApiController]
[Authorize]
[Route("api/catalog/[controller]")]
public class ExercicesTemplateController : ControllerBase
{
    private readonly CatalogDbContext _context;
    private readonly IMapper _mapper;

    public ExercicesTemplateController(CatalogDbContext context, IMapper mapper)
    {
        _context = context;
        _mapper = mapper;
    }

    [HttpPost]
    [AllowAnonymous]
    public async Task<IActionResult> Create([FromBody] CreateExerciceTemplateDto dto)
    {
        var exercice = _mapper.Map<ExerciceTemplate>(dto);
        _context.Exercices.Add(exercice);
        await _context.SaveChangesAsync();
        return CreatedAtAction(nameof(GetById), new { id = exercice.Id }, _mapper.Map<ExerciceTemplateDto>(exercice));
    }

    [HttpPut("{id}")]
    [AllowAnonymous]
    public async Task<IActionResult> Update(string id, [FromBody] UpdateExerciceTemplateDto dto)
    {
        var exercice = await _context.Exercices.FindAsync(id);
        if (exercice == null) return NotFound();

        _mapper.Map(dto, exercice);
        exercice.UpdatedAt = DateTime.UtcNow;
        await _context.SaveChangesAsync();
        return NoContent();
    }

    [HttpDelete("{id}")]
    [AllowAnonymous]
    public async Task<IActionResult> Delete(string id)
    {
        var exercice = await _context.Exercices.FindAsync(id);
        if (exercice == null) return NotFound();

        _context.Exercices.Remove(exercice);
        await _context.SaveChangesAsync();
        return NoContent();
    }

    [HttpGet("{id}")]
    [AllowAnonymous]
    public async Task<ActionResult<ExerciceTemplateDto>> GetById(string id)
    {
        var exercice = await _context.Exercices.FindAsync(id);
        if (exercice == null) return NotFound();

        return _mapper.Map<ExerciceTemplateDto>(exercice);
    }
}